Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1198)

Unified Diff: media/base/mock_media_log.h

Issue 1906423005: Replace scoped_ptr with std::unique_ptr in //media/base. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: scopedptr-media-base: android Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/mock_filters.cc ('k') | media/base/multi_channel_resampler.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/mock_media_log.h
diff --git a/media/base/mock_media_log.h b/media/base/mock_media_log.h
index f58dc1deedad82434c2df58a60ecc2a4394db702..c992fc22315b8a5be198c80e6ecbe861bffdbbb6 100644
--- a/media/base/mock_media_log.h
+++ b/media/base/mock_media_log.h
@@ -5,6 +5,7 @@
#ifndef MEDIA_BASE_MOCK_MEDIA_LOG_H_
#define MEDIA_BASE_MOCK_MEDIA_LOG_H_
+#include <memory>
#include <string>
#include "base/macros.h"
@@ -27,10 +28,10 @@ class MockMediaLog : public MediaLog {
MOCK_METHOD1(DoAddEventLogString, void(const std::string& event));
// Trampoline method to workaround GMOCK problems with scoped_ptr<>.
// Also simplifies tests to be able to string match on the log string
// representation on the added event.
- void AddEvent(scoped_ptr<MediaLogEvent> event) override {
+ void AddEvent(std::unique_ptr<MediaLogEvent> event) override {
DoAddEventLogString(MediaEventToLogString(*event));
}
« no previous file with comments | « media/base/mock_filters.cc ('k') | media/base/multi_channel_resampler.h » ('j') | no next file with comments »
@@ -27,10 +28,10 @@ class MockMediaLog : public MediaLog {
MOCK_METHOD1(DoAddEventLogString, void(const std::string& event));
- // Trampoline method to workaround GMOCK problems with scoped_ptr<>.
+ // Trampoline method to workaround GMOCK problems with std::unique_ptr<>.
// Also simplifies tests to be able to string match on the log string
// representation on the added event.

Powered by Google App Engine
This is Rietveld 408576698